pyxmpp2.mainloop.select

Package pyxmpp2 :: Package mainloop :: Module select |
[hide private]

# Module select

I/O Handling classes

This module has a purpose similar to `asyncore` from the base library, but should be more usable, especially for PyXMPP.

Also, these interfaces should allow building application not only in asynchronous event loop model, but also threaded model.

Classes | [hide private]
| SelectMainLoop Main event loop implementation based on the select.select() call.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.mainloop.select")`